==> tine20-allinone_2019.12.5.tar.bz2: ActiveSync/js/ActiveSync-lang-sk-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Slovak (http://www.transifex.com/tine20/tine20/language/sk/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sk\nPlural-Forms: nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "SyncDevice, SyncDevices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Sync Devices"
: ""

, "ID"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "AS Version"
: ""

, "Useragent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendarfilter"
: ""

, "Contactsfilter"
: ""

, "Emailfilter"
: ""

, "Tasksfilter"
: ""

, "Last Ping"
: ""

, "Remote Reset Device"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device is reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Device, Devices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Devices"
: ""

, "Active Sync"
: ""

, "Select a Device"
: ""

, "No ActiveSync Device registered"
: ""

, "Set as {0} Filter"
: ""

, "Resetted Sync Filter"
: ""

, "{0} filter for device \"{1}\" is now \"{2}\""
: ""

, "resetted"
: ""

, "Set Sync Filter"
: ""

, "Default Addressbook"
: ""

, "The default addressbook to create new contacts in."
: ""

, "Default Calendar"
: ""

, "The default calendar to create new events in."
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Default policy for new devices"
: ""

, "Enter the id of the policy to apply to newly created devices."
: ""

, "Disable Access Log"
: ""

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for emails"
: ""

, "For how long in the past the emails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Default Policy"
: ""

, "Default Policy installed during setup"
: ""

, "SyncDevice"
: ""

, "Device"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: ActiveSync/js/ActiveSync-lang-sk-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Slovak (http://www.transifex.com/tine20/tine20/language/sk/)\nLanguage: sk\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: ""

, "The default calendar to create new events in."
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Sync Devices"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Sync Device, Sync Devices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Device, Devices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Devices"
: ""

, "Active Sync"
: ""

, "Select a Device"
: ""

, "No ActiveSync Device registered"
: ""

, "Set as {0} Filter"
: ""

, "Resetted Sync Filter"
: ""

, "{0} filter for device \"{1}\" is now \"{2}\""
: ""

, "resetted"
: ""

, "Set Sync Filter"
: ""

, "ID"
: ""

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Default Policy"
: ""

, "Default Policy installed during setup"
: ""

, "Default policy for new devices"
: ""

, "Enter the id of the policy to apply to newly created devices."
: ""

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: ""

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Sync Device"
: ""

, "Device"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
